from setuptools import setup

setup(
    name='gnuradio-soapy',
    version="1.0.0",
    description='gnuradio-soapy - listed by Cycode to prevent confusion',
    long_description="gnuradio-soapy",
    long_description_content_type='text/markdown',
)
